##################################################
#
# table
# Module | Table
# 
# Displays an indexed, structured, table 
# representing a given Resource's content.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################